@@ -6,16 +6,16 @@ mod row_group;
 pub(self) mod statistics;
 
 #[cfg(feature = "stream")]
-pub mod stream;
+mod stream;
 #[cfg(feature = "stream")]
-mod stream_stream;
+pub use stream::FileStreamer;
 
 mod dyn_iter;
 pub use dyn_iter::{DynIter, DynStreamingIterator};
 
 pub use compression::{compress, Compressor};
 
-pub use file::write_file;
+pub use file::FileWriter;
 
 use crate::compression::Compression;
 use crate::page::CompressedPage;
@@ -23,13 +23,18 @@ use crate::page::CompressedPage;
 pub type RowGroupIter<'a, E> =
     DynIter<'a, std::result::Result<DynStreamingIterator<'a, CompressedPage, E>, E>>;
 
+/// Write options of different interfaces on this crate
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub struct WriteOptions {
+    /// Whether to write statistics
     pub write_statistics: bool,
+    /// Whether to use compression
     pub compression: Compression,
+    /// Which Parquet version to use
     pub version: Version,
 }
 
+/// The parquet version to use
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash)]
 pub enum Version {
     V1,
